diff --git a/django/contrib/formtools/tests/wizard/__init__.py b/django/contrib/formtools/tests/wizard/__init__.py
index dce2fed..85d2b73 100644
--- a/django/contrib/formtools/tests/wizard/__init__.py
+++ b/django/contrib/formtools/tests/wizard/__init__.py
@@ -4,8 +4,8 @@ from django.contrib.formtools.tests.wizard.loadstorage import TestLoadStorage
 from django.contrib.formtools.tests.wizard.namedwizardtests.tests import (
     NamedSessionWizardTests,
     NamedCookieWizardTests,
-    TestNamedUrlSessionFormWizard,
-    TestNamedUrlCookieFormWizard,
+    TestNamedUrlSessionWizardView,
+    TestNamedUrlCookieWizardView,
     NamedSessionFormTests,
     NamedCookieFormTests,
 )
diff --git a/django/contrib/formtools/tests/wizard/namedwizardtests/tests.py b/django/contrib/formtools/tests/wizard/namedwizardtests/tests.py
index 0f63882..3870dea 100644
--- a/django/contrib/formtools/tests/wizard/namedwizardtests/tests.py
+++ b/django/contrib/formtools/tests/wizard/namedwizardtests/tests.py
@@ -319,24 +319,24 @@ class NamedFormTests(object):
         instance.render_done(None)
         self.assertEqual(instance.storage.current_step, 'start')
 
-class TestNamedUrlSessionFormWizard(NamedUrlSessionWizardView):
+class TestNamedUrlSessionWizardView(NamedUrlSessionWizardView):
 
     def dispatch(self, request, *args, **kwargs):
-        response = super(TestNamedUrlSessionFormWizard, self).dispatch(request, *args, **kwargs)
+        response = super(TestNamedUrlSessionWizardView, self).dispatch(request, *args, **kwargs)
         return response, self
 
-class TestNamedUrlCookieFormWizard(NamedUrlCookieWizardView):
+class TestNamedUrlCookieWizardView(NamedUrlCookieWizardView):
 
     def dispatch(self, request, *args, **kwargs):
-        response = super(TestNamedUrlCookieFormWizard, self).dispatch(request, *args, **kwargs)
+        response = super(TestNamedUrlCookieWizardView, self).dispatch(request, *args, **kwargs)
         return response, self
 
 
 class NamedSessionFormTests(NamedFormTests, TestCase):
-    formwizard_class = TestNamedUrlSessionFormWizard
+    formwizard_class = TestNamedUrlSessionWizardView
     wizard_urlname = 'nwiz_session'
 
 
 class NamedCookieFormTests(NamedFormTests, TestCase):
-    formwizard_class = TestNamedUrlCookieFormWizard
+    formwizard_class = TestNamedUrlCookieWizardView
     wizard_urlname = 'nwiz_cookie'
diff --git a/django/contrib/formtools/wizard/storage/cookie.py b/django/contrib/formtools/wizard/storage/cookie.py
index af26e01..d1776de 100644
--- a/django/contrib/formtools/wizard/storage/cookie.py
+++ b/django/contrib/formtools/wizard/storage/cookie.py
@@ -20,7 +20,7 @@ class CookieStorage(storage.BaseStorage):
         except KeyError:
             data = None
         except BadSignature:
-            raise SuspiciousOperation('FormWizard cookie manipulated')
+            raise SuspiciousOperation('WizardView cookie manipulated')
         if data is None:
             return None
         return json.loads(data, cls=json.JSONDecoder)
diff --git a/django/contrib/formtools/wizard/views.py b/django/contrib/formtools/wizard/views.py
index 15ba146..badb2bf 100644
--- a/django/contrib/formtools/wizard/views.py
+++ b/django/contrib/formtools/wizard/views.py
@@ -102,9 +102,9 @@ class WizardView(TemplateView):
     @classonlymethod
     def as_view(cls, *args, **kwargs):
         """
         This method is used within urls.py to create unique formwizard
         instances for every request. We need to override this method because
         we add some kwargs which are needed to make the formwizard usable.
         """
         initkwargs = cls.get_initkwargs(*args, **kwargs)
         return super(WizardView, cls).as_view(**initkwargs)
@@ -117,7 +117,7 @@ class WizardView(TemplateView):
 
         * `form_list` - is a list of forms. The list entries can be single form
           classes or tuples of (`step_name`, `form_class`). If you pass a list
           of forms, the formwizard will convert the class list to
           (`zero_based_counter`, `form_class`). This is needed to access the
           form for a specific step.
         * `initial_dict` - contains a dictionary of initial data dictionaries.
@@ -130,7 +130,7 @@ class WizardView(TemplateView):
           apply.
         * `condition_dict` - contains a dictionary of boolean values or
           callables. If the value of for a specific `step_name` is callable it
           will be called with the formwizard instance as the only argument.
           If the return value is true, the step's form will be used.
         """
         kwargs.update({
@@ -159,13 +159,13 @@ class WizardView(TemplateView):
                 # we need to override the form variable.
                 form = form.form
             # check if any form contains a FileField, if yes, we need a
             # file_storage added to the formwizard (by subclassing).
             for field in form.base_fields.itervalues():
                 if (isinstance(field, forms.FileField) and
                         not hasattr(cls, 'file_storage')):
                     raise NoFileStorageConfigured
 
         # build the kwargs for the formwizard instances
         kwargs['form_list'] = init_form_list
         return kwargs
 
@@ -209,7 +209,7 @@ class WizardView(TemplateView):
         After processing the request using the `dispatch` method, the
         response gets updated by the storage engine (for example add cookies).
         """
         # add the storage engine to the current formwizard instance
         self.wizard_name = self.get_wizard_name()
         self.prefix = self.get_prefix()
         self.storage = get_storage(self.storage_name, self.prefix, request,
@@ -512,7 +512,7 @@ class WizardView(TemplateView):
 
         .. code-block:: python
 
-            class MyWizard(FormWizard):
+            class MyWizard(WizardView):
                 def get_context_data(self, form, **kwargs):
                     context = super(MyWizard, self).get_context_data(form, **kwargs)
                     if self.steps.current == 'my_step_name':
@@ -636,7 +636,7 @@ class NamedUrlWizardView(WizardView):
     def post(self, *args, **kwargs):
         """
         Do a redirect if user presses the prev. step button. The rest of this
-        is super'd from FormWizard.
+        is super'd from WizardView.
         """
         prev_step = self.request.POST.get('wizard_prev_step', None)
         if prev_step and prev_step in self.get_form_list():
@@ -646,7 +646,7 @@ class NamedUrlWizardView(WizardView):
 
     def render_next_step(self, form, **kwargs):
         """
         When using the NamedUrlFormWizard, we have to redirect to update the
         browser's URL to match the shown step.
         """
         next_step = self.get_next_step()
@@ -680,7 +680,7 @@ class NamedUrlSessionWizardView(NamedUrlWizardView):
 
 class NamedUrlCookieWizardView(NamedUrlWizardView):
     """
     A NamedUrlFormWizard with pre-configured CookieStorageBackend.
     """
     storage_name = 'django.contrib.formtools.wizard.storage.cookie.CookieStorage'
 
@@ -102,9 +102,9 @@ class WizardView(TemplateView):
     def as_view(cls, *args, **kwargs):
         """
-        This method is used within urls.py to create unique formwizard
+        This method is used within urls.py to create unique wizardview
         instances for every request. We need to override this method because
@@ -102,9 +102,9 @@ class WizardView(TemplateView):
         instances for every request. We need to override this method because
-        we add some kwargs which are needed to make the formwizard usable.
+        we add some kwargs which are needed to make the wizardview usable.
         """
         initkwargs = cls.get_initkwargs(*args, **kwargs)
@@ -117,7 +117,7 @@ class WizardView(TemplateView):
         * `form_list` - is a list of forms. The list entries can be single form
           classes or tuples of (`step_name`, `form_class`). If you pass a list
-          of forms, the formwizard will convert the class list to
+          of forms, the wizardview will convert the class list to
           (`zero_based_counter`, `form_class`). This is needed to access the
           form for a specific step.
@@ -130,7 +130,7 @@ class WizardView(TemplateView):
         * `condition_dict` - contains a dictionary of boolean values or
           callables. If the value of for a specific `step_name` is callable it
-          will be called with the formwizard instance as the only argument.
+          will be called with the wizardview instance as the only argument.
           If the return value is true, the step's form will be used.
         """
@@ -159,13 +159,13 @@ class WizardView(TemplateView):
                 form = form.form
             # check if any form contains a FileField, if yes, we need a
-            # file_storage added to the formwizard (by subclassing).
+            # file_storage added to the wizardview (by subclassing).
             for field in form.base_fields.itervalues():
                 if (isinstance(field, forms.FileField) and
@@ -159,13 +159,13 @@ class WizardView(TemplateView):
                     raise NoFileStorageConfigured
 
-        # build the kwargs for the formwizard instances
+        # build the kwargs for the wizardview instances
         kwargs['form_list'] = init_form_list
         return kwargs
@@ -209,7 +209,7 @@ class WizardView(TemplateView):
         response gets updated by the storage engine (for example add cookies).
         """
-        # add the storage engine to the current formwizard instance
+        # add the storage engine to the current wizardview instance
         self.wizard_name = self.get_wizard_name()
         self.prefix = self.get_prefix()
@@ -646,7 +646,7 @@ class NamedUrlWizardView(WizardView):
     def render_next_step(self, form, **kwargs):
         """
-        When using the NamedUrlFormWizard, we have to redirect to update the
+        When using the NamedUrlWizardView, we have to redirect to update the
         browser's URL to match the shown step.
         """
@@ -680,7 +680,7 @@ class NamedUrlSessionWizardView(NamedUrlWizardView):
 class NamedUrlCookieWizardView(NamedUrlWizardView):
     """
-    A NamedUrlFormWizard with pre-configured CookieStorageBackend.
+    A NamedUrlWizardView with pre-configured CookieStorageBackend.
     """
     storage_name = 'django.contrib.formtools.wizard.storage.cookie.CookieStorage'
